Thanks! It’s twice as fast now:
$ time elixir test.exs ../data_gen/posts.csv
real 0m12.135s
user 0m11.734s
sys 0m0.807s
(using this code)
def run(file_name) do
File.stream!(file_name, [:read])
|> Enum.each(&process_line/1)
end
Still twice as slow as Ruby though… ![]()
Any other tips? Thanks again.


















